@@ -9,7 +9,7 @@ use warnings;
 
 use v5.26;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use Types::Standard qw[ Str ArrayRef StrMatch Enum Bool Optional Dict ];
 use Types::Common::Numeric qw[ PositiveOrZeroInt PositiveInt ];
@@ -643,7 +643,7 @@ sub parse_filename ( $, $filename ) {
     }
 
     # remove undefined entries
-    delete %match { grep ! defined $match{$_}, keys %match };
+    delete @match { grep ! defined $match{$_}, keys %match };
 
     \%match;
 }
@@ -856,7 +856,7 @@ Astro::FITS::CFITSIO::FileName - parse and generate CFITSIO extended file names.
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
